import dill
from os.path import exists

# convenient dill load function
def load(fname):
    with open(fname, 'rb') as f:
        return dill.load(f)
    return

# convenient dill save function
def save(thing, fname):
    with open(fname, 'wb') as f:
        return dill.dump(thing, f)
    return

# checks if file exists, if it doesn't
# it saves the default thing to the file
# AND returns the default thing
def defaultLoad(default_thing, fname):
    if exists(fname):
        return load(fname)
    else:
        save(default_thing, fname)
        return default_thing
    return

# if you need more fine-grained control of dill
# Don't use this 'library'


#!/usr/bin/env python

f = open('./README.md', 'r')
from setuptools import setup    
setup(name='qdill',
      version='1.1',
      description='tiny convenience lib for dill',
      long_description= f.read(),
      long_description_content_type='text/markdown',
      author='madgen',
      author_email='madgencontent@gmail.com',
      url='https://github.com/madgen-content/qdill',
      install_requires=['dill'],
      packages=['qdill']
     )
f.close()